# -*- coding:utf-8 -*-

'''
		Este é o arquivo de setup do modulo "printList.py"
		não mude nenhuma linha deste arquivo isso podera
		comprometer a instalação do modulo.
		
		@Author: Jimmie Haskell
		@Date 27/11/2015
		@email: haskell4228@gmail.com
'''

from distutils.core import setup

setup(
	name 					= 'plst',
	version 			= '1.1.0',
	py_modules 		= ['plst'],
	author 				= 'Jimmie Haskell',
	author_email 	= 'haskell4228@gmail.com',
	url 					= 'http://www.facebook.com/jimmiehaskell',
	description 	='A simple function that prints nested lists.',
)

